@@ -7,8 +7,8 @@
     Could be enabled/disabled/easier to modify)
 """
 
-from async_scheduler.job import Job
+from async_scheduler.job import BaseJob
 from async_scheduler.scheduler import Scheduler
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
