@@ -6,7 +6,7 @@ class SchedulerExecutionError(TypeError):
     pass
 
 
-class DuplicateUserError(BaseException):
+class DuplicateJobError(BaseException):
     pass
 
 
